#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END

#
# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------


# Script to ping the given IPAddress
# until success or until given timeout value
# and return an exit code of zero or 127 
# signifying target is alive or not responding.
#
# Average ping time is echoed to stdout.
# Last unsuccessful ping output is echoed to stderr.
#
# Called by "ICMP Ping IP" workflow.
# 
# Written in hoary and venerable Bourne shell script,
# thus will work from Windows/Cygwin, Linux, SunOS, and AIX.
#
# Nov 19, 2003	- Partha Kaushik: First Creation of Script
#

ProgName=`basename $0`
if (test $# -ne 2)
then echo "Usage $ProgName IPAddress timeout-in-secs" 1>&2
     exit 1
fi

# Input Args
IPAddress=$1
TIMEOUT=$2



# Get the manage-from OS 
OS=`uname -o`
case $OS in
Cygwin)               # We got Cygwin
       PINGTEST="ping -n 3 127.0.0.1"
       ;; 
     *) OS=`uname -s` 
        case $OS in 
           SunOS) 
                 PINGTEST="/usr/sbin/ping -s 127.0.0.1 56 3"
                 ;;
      AIX|Linux)
                 PINGTEST="ping -c 3 127.0.0.1"                 
                 ;;
              *) # Unknown OS
                 echo -1
                 echo "Not Cygwin or SunOS or AIX or Linux, unsupported platform" 1>&2
                 exit 127
                 ;;
         esac
       ;;
esac
# echo $OS

# Test Ping itself does not fail
TST=`$PINGTEST`
case $? in
  0) 
    # Ping is okay, proceed
  ;;
  *)
    # PING command dinnae work, set result (PINGTIME) to -1 and exit
    echo "-1"
    # echo $PINGTIME
    exit 127
  ;;
esac

HR=`date +%H`; MIN=`date +%M`; SEC=`date +%S`     # Get the HR:MIN:SEC 
SECNOW=`expr $HR '*' 3600 + $MIN '*' 60 + $SEC`   # Convert to secs since midnight
SECEND=`expr $SECNOW + $TIMEOUT + 1`              # value for timeout decision

# 
until ( test $SECNOW -gt $SECEND ) 
do
   HRNOW=`date +%H`; MIN=`date +%M`; SEC=`date +%S`    # Get the HR:MIN:SEC 
   SECNOW=`expr $HRNOW '*' 3600 + $MIN '*' 60 + $SEC`  # Convert to secs since midnight
   if [ `expr $HRNOW \< $HR` -eq "1" ]                 # Take account of 
   then SECNOW=`expr $SECNOW + 86400` ; fi             # the twilight zone

   case $OS in
       Cygwin) 
              CODE=`ping -n 9 $IPAddress`
               echo $CODE | grep "Packets: Sent = 9, Received = 0, Lost = 9 (100% loss)" 1>&2
                case $? in 
                   0)                      # grep is successful, so machine is dead
                   ;;
                   *)                      # grep is unsuccessful, so machine is alive
                      echo `expr "$CODE" : '.*Average = \([\., ,0-9]*\)ms.*'`
                      exit 0	        
                   ;;
                 esac
              ;;
              
      AIX|Linux)    
                CODE=`ping -c 9 $IPAddress`
		echo $CODE | grep "9 packets transmitted, 0 packets received" 1>&2
                case $? in 
                   0)                      # grep is successful, so machine is dead
                   ;;
                   *)                      # grep is unsuccessful, so machine is alive
                      # echo $CODE
                      echo `expr "$CODE" : '.*= .*\/\([\., ,0-9]*\)\/.*'`
                      exit 0	        
                   ;;
                 esac
               ;;
               
         SunOS)
               CODE=`/usr/sbin/ping -s $IPAddress 56 9 `
               echo $CODE | grep "9 packets transmitted, 0 packets received, 100% packet loss" 1>&2
               case $? in 
                   0)                     # grep is successful, so machine is dead
                     ;; # do not exit but loopback to the do-until                   
                     
                   *)                     # grep is unsuccessful, so machine is alive
                      # echo $CODE
                      echo `expr "$CODE" : '.*max = .*\/\([\.,0-9]*\)\/'`
                      exit 0	        
                   ;;
                esac                
              ;;               
               
   esac
done

echo "-1"
exit 127
