#!/usr/bin/env sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END


# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004, 2009
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#/**
# * Modifies SNMP credentials - shell script
# *   
# */


#set -x
cmd_line=$@

#***************************************************************************#
#      generate some basic help message                                     #
#***************************************************************************#

usage() {
        cat << EOF

Usage:  $0 {[option values] ...}

where options are:

	-help   --display this message
        -A      --RO or RW(REQUIERED)
        -C      --community (REQUIERED)

EOF
}

#***************************************************************************#
#      parse the input arguments                                            #
#***************************************************************************#

for param in "$@"
do
        case $param in
                -A)
                        shift
                        accessType=$1
                        ;;
                -C)
                        shift
                        community=$1 
                        ;;
                -help)
                        usage
                        exit 0
                        ;;
                *)
                        shift
                        ;; 
        esac
done

#***************************************************************************#
#      make sure we have all the required parameters                        #
#***************************************************************************#

if [ -z "$accessType" -o -z "$community" ]; then
        usage
        exit 1
fi

#*********************************************************#
#   Find the OS type running on the target                #
#*********************************************************#

case `uname` in
	Linux)
		awk_cmd=gawk
		os_type=linux
		;;
	CYGWIN_NT-5.0|CYGWIN_NT-5.1)
		awk_cmd=gawk
		os_type=windows
		;;
	SunOS)
		awk_cmd=nawk
		os_type=solaris
		;;
	AIX)
		awk_cmd=awk
		os_type=aix
		;;
	HP-UX)
		awk_cmd=awk
		os_type=hp-ux
		;;
	*)
		echo "Unknown operating system"
		exit 1
		;;
esac

#*********************************************************#
#   Linux community update                                #
#*********************************************************#

if [ "$os_type" = "linux" ]; then

#*********************************************************#
#   Modify the snmpd.conf file                            #
#*********************************************************#

	if [ ! -e /etc/snmp/snmpd.conf ]; then
		echo "Can not find snmpd.conf file under /etc/snmp/"
		exit 1
	fi

	roComm=`cat /etc/snmp/snmpd.conf | $awk_cmd '$0 ~ "^com2sec *readonly" {print $4}'`
	rwComm=`cat /etc/snmp/snmpd.conf | $awk_cmd '$0 ~ "^com2sec *readwrite" {print $4}'`

	if [ "$accessType" = "RO" ]; then
		roComm=$community
	elif [ "$accessType" = "RW" ]; then
		rwComm=$community
	else
		echo "Invalid community type"
		exit 1
	fi

cat << EOFEOF > /etc/snmp/snmpd.conf.$$
com2sec readonly  default         $roComm
com2sec readwrite default         $rwComm

group MyROGroup  v1         readonly
group MyROGroup  v2c        readonly
group MyROGroup  usm        readonly
group MyRWGroup  v1         readwrite
group MyRWGroup  v2c        readwrite
group MyRWGroup  usm        readwrite

view all    included  .1                               80

access MyROGroup  ""      any       noauth    exact  all    none   none
access MyRWGroup  ""      any       noauth    exact  all    all    none

syslocation Toronto
syscontact Root <root@localhost> 

disk / 10000

# Check for loads:
load 12 14 14
EOFEOF

	mv /etc/snmp/snmpd.conf.$$ /etc/snmp/snmpd.conf

	ps -ef | grep snmpd | grep -v grep
	if [ "$?" = "0" ]; then
		/etc/init.d/snmpd restart
	fi
	exit 0
fi

#*********************************************************#
#    Windows user update                                  #
#*********************************************************#

if [ "$os_type" = "windows" ]; then

	regedit /E snmp-community.$$ "HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Services\SNMP\Parameters\ValidCommunities"

	roComm=`cat snmp-community.$$ | tr -d '\000' | gawk 'BEGIN { FS= "\"" }; /00000004/ { print $2 }'`
	rwComm=`cat snmp-community.$$ | tr -d '\000' | gawk 'BEGIN { FS= "\"" }; /00000008/ { print $2 }'`

	if [ "$accessType" = "RO" ]; then
		roComm=$community
	elif [ "$accessType" = "RW" ]; then
		rwComm=$community
	else
		echo "Invalid community type"
		exit 1
	fi

	if [ -z "$roComm" ]; then
		roKey=""
	else
		roKey="\"$roComm\"=dword:00000004"
	fi

	if [ -z "$rwComm" ]; then
		rwKey=""
	else
		rwKey="\"$rwComm\"=dword:00000008"
	fi

#*********************************************************#
#    Clean up the existing snmp-communities               #
#*********************************************************#

cat << EOFEOF > snmp-community.$$
Windows Registry Editor Version 5.00

[-HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Services\SNMP\Parameters\ValidCommunities]
EOFEOF

	regedit /S snmp-community.$$

#*********************************************************#
#    Create the new snmp-communities                      #
#*********************************************************#

cat << EOFEOF > snmp-community.$$
Windows Registry Editor Version 5.00

[HKEY_LOCAL_MACHINE\SYSTEM\ControlSet001\Services\SNMP\Parameters\ValidCommunities]
$roKey
$rwKey
EOFEOF

	regedit /S snmp-community.$$
	rm snmp-community.$$
	exit 0
fi

#*********************************************************#
#             Solaris Community Update                    #
#*********************************************************#
if [ "$os_type" = "solaris" ] ; then

	if [ ! -e /etc/snmp/conf/snmpd.conf ]; then
		echo "Can not find snmpd.conf file under /etc/snmp/conf/"
		exit 1
	fi


	roComm=`cat /etc/snmp/conf/snmpd.conf | $awk_cmd '/^read-community*/  {print $2}'`
	rwComm=`cat /etc/snmp/conf/snmpd.conf | $awk_cmd '/^write-community*/ {print $2}'`
	
	
	if [ "$accessType" = "RO" ]; then
		roComm=$community
	elif [ "$accessType" = "RW" ]; then
		rwComm=$community
	else
		echo "Invalid community type"
		exit 1
	fi
	
cat << EOFEOF > /etc/snmp/conf/snmpd.conf.$$

sysdescr	Sun SNMP Agent, Sun - Fire
syscontact	System administrator
syslocation	System administrators office

system-group-read-community	$roComm
system-group-write-community	$rwComm

read-community	$roComm
write-community	$rwComm

trap localhost
trap-community SNMP-trap

managers localhost

EOFEOF

	mv /etc/snmp/conf/snmpd.conf.$$ /etc/snmp/conf/snmpd.conf

	ps -ef | grep snmpd | grep -v grep
	
	if [ "$?" = "0" ]; then
	
		/usr/sbin/snmpd 
	fi
	
	exit 0

fi
#*********************************************************#
#            End of Solaris Community Update              #
#*********************************************************#

#*********************************************************#
#                AIX Community Update                     #
#*********************************************************#
if [ "$os_type" = "aix" ] ; then


	if [ ! -e /etc/snmpd.conf ]; then
		echo "Can not find snmpd.conf file under /etc"
		exit 1
	fi

	roComm=`cat /etc/snmpd.conf | $awk_cmd '$0 ~ /community/ && /readOnly/ {print $2}'`
	rwComm=`cat /etc/snmpd.conf | $awk_cmd '$0 ~ /community/ && /readWrite/ {print $2}'`
	
	if [ "$accessType" = "RO" ]; then
		roComm=$community
	elif [ "$accessType" = "RW" ]; then
		rwComm=$community
	else
		echo "Invalid community type"
		exit 1
	fi



cat<<EOFEOF > /etc/snmpd.conf.$$

logging		file=/usr/tmp/snmpd.log		enabled
logging		size=0						level=0

community $roComm 127.0.0.1	255.255.255.255 readOnly
community $rwComm 127.0.0.1	255.255.255.255	readWrite

view 1.17.2		

syscontact Root <root@localhost>
syslocation Toronto

EOFEOF


	mv /etc/snmpd.conf.$$ /etc/snmpd.conf

	ps -ef | grep snmpd | grep -v grep
	
	if [ "$?" = "0" ]; then
	
		/usr/sbin/snmpd 
	fi
	
	exit 0

fi
#*********************************************************#
#              End of AIX Community Update                #
#*********************************************************#
#*********************************************************#
#                HP-UX Community Update                   #
#*********************************************************#
if [ "$os_type" = "hp-ux" ] ; then

	if [ ! -e /etc/snmpd.conf ]; then
		echo "Can not find snmpd.conf file under /etc"
		exit 1
	fi

	roComm=`cat /etc/snmpd.conf | $awk_cmd '/^get-community-name*/  {print $2}'`
	rwComm=`cat /etc/snmpd.conf | $awk_cmd '/^set-community-name*/ {print $2}'`
	
	
	if [ "$accessType" = "RO" ]; then
		roComm=$community
	elif [ "$accessType" = "RW" ]; then
		rwComm=$community
	else
		echo "Invalid community type"
		exit 1
	fi
	
cat << EOFEOF > /etc/snmpd.conf.$$

get-community-name: $roComm
set-community-name: $rwComm
trap-dest:	127.0.0.1
contact:	System Administrator (Phone# xxx-xxx-xxxx)
location:	System Administrators Office

EOFEOF

		mv /etc/snmpd.conf.$$ /etc/snmpd.conf

		ps -ef | grep snmpdm | grep -v grep
		
		if [ "$?" = "1" ]; then
			/sbin/init.d/SnmpMaster start
		else
			/sbin/init.d/SnmpMaster stop
			sleep 2
			/sbin/init.d/SnmpMaster start
		fi
	
	exit 0

fi
#*********************************************************#
#             End of HP-UX Community Update               #
#*********************************************************#
echo "Unknown operating system"
exit 1

