#!/usr/bin/env sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END


# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004, 2009
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#/**
# * Remove PWD credentials script
# *   
# */


#set -x
cmd_line=$@

#############################################################################
##     generate some basic help message                                    ##
#############################################################################

usage() {
        cat << EOF

Usage:  $0 {[option values] ...}

where options are:

	-help   --display this message
        -U      --username (REQUIERED)

EOF
}

#############################################################################
##     parse the input arguments                                           ##
#############################################################################

for param in "$@"
do
        case $param in
                -U)
                        shift
                        username=$1
                        ;;
                -help)
                        usage
                        exit 0
                        ;;
                *)
                        shift
                        ;; 
        esac
done

#############################################################################
##     make sure we have all the required parameters                       ##
#############################################################################

if [ -z "$username" ]; then
        usage
        exit 1
fi

#*********************************************************#
#   Find the OS type running on the target                #
#*********************************************************#

case `uname` in
	Linux)
		awk_cmd=gawk
		os_type=linux
		;;
	CYGWIN_NT-5.0|CYGWIN_NT-5.1)
		awk_cmd=gawk
		os_type=windows
		;;
	SunOS)
		awk_cmd=nawk
		os_type=solaris
		;;
	*)
		echo "Unknown operating system"
		exit 1
		;;
esac

#*********************************************************#
#   Linux and Solaris user update                         #
#*********************************************************#

if [ "$os_type" = "linux" -o "$os_type" = "solaris" ]; then

#*********************************************************#
#   Delete the account                                    #
#*********************************************************#

	if [ ! `cat /etc/passwd | $awk_cmd 'BEGIN { FS = ":" }; $0 ~ username { print $1 }' username=^$username:` ]; then
		echo "Invalid User"
		exit 1
	fi
	
	userdel -r $username

	if [ $? -eq 0 ]; then
		echo "Account deleted"
		exit 0
	else
		echo "Unable to delete account"
		exit 1
	fi
fi

#*********************************************************#
#    Windows user update                                  #
#*********************************************************#

if [ "$os_type" = "windows" ]; then

        if [ ! `cat /etc/passwd | $awk_cmd 'BEGIN { FS = ":" }; $0 ~ username { print $1 }' username=^$username:` ]; then
                echo "Invalid User"
                exit 1
        fi
	
	net user $username /delete
	if [ ! $? -eq 0 ]; then
		echo "Can not delete the user"
		exit 1
	fi

#        cat /etc/passwd | $awk_cmd 'BEGIN { FS = ":" }; $0 !~ username \
#                {print $0}' username=^$username: > /etc/passwd.$$

	mkpasswd -l > /etc/passwd.$$

	if [ `mv /etc/passwd.$$ /etc/passwd` ]; then
		echo "Error updating the passwd file"
		exit 1
	fi

	rm -fr /home/$username
	if [ $? -eq 0 ]; then
		echo "Account deleted"
		exit 0
	else	
		echo "Unable to delete account"
		exit 1
	fi
fi

echo "Unknown operating system"
exit 1

