# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END

#  
# ======================================================================= 

if [ $# -ne 5 ]; then
    echo "Error in $0 - Invalid Argument Count"
    echo "Syntax: $0 fileName filePath section(optional) varName newValue delimiter"
    exit
fi

fileName=$1
filePath=$2
section=$3
varName=$4
newValue=$5
delim=$6

cd $filePath
[ ! -w $fileName ] &&{
	echo "The file does not exist at the following path:  $filePath/$fileName" 1>&2
    exit 1
}

cp $fileName $fileName.backup

echo ""

#If no section is specified, remediate all instances of the variable
if [ -z $section ]; then
	echo "
		! /^[ \t]*$varName[ \t]*$delim/	{ print }
		 /^[ \t]*$varName[ \t]*$delim/	{ if ( \$2 ~ /^ / ) { new = \$1\"$delim \" \"$newValue\";} 
											else { new = \$1\"$delim\" \"$newValue\" }
	            						print new;} 
	            	" > script.awk
	            	
#if a section is specified, remediate only the instances of the variable that appear in that section
else
	echo "
		BEGIN          { insection=\"false\" } 
		#print all lines that do not match the section or variable
		! /^[ \t]*$varName[ \t]*$delim|^[ \t]*$section[ \t]*$/	{ print; }
		#If the the specified section is found, set the "insection" flag to true
		/^[ \t]*$section[ \t]*$/	{ 	print;
										insection=\"true\";
									 }
		#If the variable is found, and it is in the correct section, replace its value with the new one.
		#Since we are assuming that there is only one instance of the variable per section, 
		#after we find an instance of the variable in the specified section, set the "insection" flag back to false.
		/^[ \t]*$varName[ \t]*$delim/	{ if ( insection == \"true\") {
											if ( \$2 ~ /^ / ) { new = \$1\"$delim \" \"$newValue\"} 
											else { new = \$1\"$delim\" \"$newValue\" }						
	             						}
	            						else {
	            							new = \$1\"$delim\"\$2;
	            						}
	            							print new;
	            							insection=\"false\";
	            						} 
				" > script.awk
fi

awk -F$delim -f script.awk $fileName.backup > $fileName

rm -f script.awk
