# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END


#  
# ======================================================================= 

# filename: execute.sh
# Execute sh script
#
proc TIOthrow {exception message} {

   regsub -all {&} $message "\\&amp;" message
   regsub -all {\%} $message "\\&#37;" message
   regsub -all {\"} $message "\\&quot;" message
   regsub -all {<} $message "\\&lt;" message
   regsub -all {>} $message "\\&gt;" message

   puts "<tio><throw exception=\"$exception\">$message</throw></tio>"
}

expect {
  -re "$PROMPT$" {send "cd $SCRIPT_DIR\r"}
}

# set workflow variables
# @TODO escape variable values!
foreach {var val} [array get wfvars] {
  regsub -all {'} $val "'\\''" val
  expect {
    -re "$PROMPT$" {send "$var=\'$val\'\r"}
  }
}

expect {
   -re "$PROMPT$" {send "set_options_before=`echo \x24-`\r"}
}

expect {
   -re "$PROMPT$" { send ". ./$SCRIPT_NAME\r" }
}

expect -exact "$SCRIPT_NAME"

send  "\r"


# process the TIOlog tags first.
# after that we will restore the "set" settings
expect {

  -ex "</tio>" {
     puts "$expect_out(buffer)"
     exp_continue
  }
  -re "EXITCODE-\[0-9]+-EXITCODE" {
     set exit_buffer $expect_out(buffer)
  }
  -re "$PROMPT$" {
     set error_message "$expect_out(buffer)"
     send "echo EXITCODE-$?-EXITCODE\r"
     exp_continue
  }
}

# delete all "set" settings
expect {
    -re "$PROMPT$" {send "set_options_after=`echo \x24-`\r"}
}
expect {
    -re "$PROMPT$" {send "set +\x24set_options_after\r"}
}

# restore the original "set" settings
expect {
    -re "$PROMPT$" {send "set -\x24set_options_before\r"}
}


regexp {([0-9]+)} $exit_buffer -> exit_code
if { $exit_code != 0 }  {
    TIOthrow ScriptletFailed "The scriptlet exited with code $exit_code. $error_message"
}

expect {
    -re "$PROMPT$" { send "exit\r" }
}

if [info exists prompt] { 
expect {
    -re "$prompt" { send "exit\r" }
   }
}

